% beregning av motstand og induktans avhengig av skinneffekt: 

% Formelene er gjeldende for en enkel sikrulær leder, som er i en leder-løkke som ikke 
% er påvirket av utenforliggende felt eller at avstand mellom lederne i
% løkken er så stor at proximity-effekten blir liten (radius_leder <<
% separasjonsavstand)

clear
clc
close all

%% Parametre

% parametere inngang
u0         = 4*pi*1e-7;                                                     % Permeabilitet konstant (H/m), vakuum
rho        = 1.8335e-8;                                                     % Resistivitet (Ohm*m), kopper 
l_m        = 1;                                                             % leder-lengde en vei (m)
f          = 1:100000;                                                      % frekvens (Hz)
A          = 95e-6;                                                         % tverrsnitt leder (m^2)
T0         = 20;                                                            % temperatur 0-faktor
T1         = 80;                                                            % Temperatur i kabelen
Alfa       = 3.9*10^-3;                                                     % Temperaturkoeffisent (K^-1), kobber

% mellomliggende parameter
r_m        = sqrt(A/pi);                                                    % Wire-Radius in (m)
rho_T1     = rho + Alfa * rho * (T1 - T0);                                  % omregning temperatur som funksjon av rho
sigma      = 1./rho_T1;                                                     % Konduktivitet, (S/m)
omega      = 2.*pi.*f;                                                      % angular frequency (Hz)
R_DC       = l_m./(sigma.*A);                                               % DC-Resistans (Ohm/m)
Linternal  = ((u0*l_m)/(8*pi));                                             % intern induktans ved lav frekvens
Lexternal  = ((u0 * l_m) / (2*pi)) * (log((2*l_m)/(r_m))-1);                % ekstern induktans

% parametre utgang
z_math     =  Z_wire (omega, r_m, sigma, u0);                               % intern-impedanse for lederen;
L_H        =  (imag(z_math)./omega).*l_m;                                   % total-induktans i lederen
R_ohm      =  real(z_math).*l_m;                                            % total-motstand i lederen


%% Neikirk ladder

skinndybde_max = 1./(sqrt(2*pi*40000*sigma.*u0./2));                        % definerer frekvens-rekkevidden til ladder
alpha_R = 0.53*(r_m./skinndybde_max);                                       % motstanskonstant avhengig av radius og definert frekvensrekkevidde
alpha_L = 0.315*alpha_R;                                                    % induktanskonstant avhengig av radius og definert frekvensrekkevidde
                                                                            
RR      = 1.35;                                                             % motstandskonstant som er iterert manuelt til å passe med bessel
LL      = 0.69;                                                             % induktanskonstant som er iterert manuelt til å passe med bessel

% Delmotstander
R1      = R_DC*alpha_R;
R2      = R1./RR;
R3      = R2./RR;
R4      = R3./RR;

% Delinduktanser
L1      = Linternal./alpha_L;
L2      = L1./LL;
L3      = L2./LL;

% Delreaktanser
XL1     = L1.*omega;
XL2     = L2.*omega;
XL3     = L3.*omega;

%forenkler kretsen for å finne totalverdier
first   = R4 + 1j * XL3;
second  = ((first .* R3) ./ (first + R3));
third   = 1j.*XL2 + second;
fourth  = ((third .* R2) ./ (third + R2));
fifth   = fourth + 1j * XL3;

%Totalverdier i Neikirk-ladder
Ladder_Z_tot_ohm   = ((fifth .* R1) ./ ( fifth + R1));
Ladder_R_tot_ohm   = real(Ladder_Z_tot_ohm);
Ladder_L_tot_H     = imag(Ladder_Z_tot_ohm)./omega;

%% feil i prosent mellom bessel og neikirk-ladder
x           = 15800;                                                        % Referansepunkt for beregning av forskjell (x-akse)
Forskjell_L = 100 * ((Ladder_L_tot_H(x)-L_H(x))/L_H(x))                     % Forskjell induktans
forskjell_R = 100 * ((Ladder_R_tot_ohm(x)-R_ohm(x))/R_ohm(x))               % Forskjell motstand

%% plot over motstand og induktans avhengig av frekvens

figure
xlabel('Frekvens (Hz)')
title('Motstand og induktans i leder')

grid on

%graf venstre akse (Motstand)
yyaxis left                                                                 % Definerer venstre Y-akse
semilogx(f,R_ohm, '--','DisplayName','bessel: motstand')                    % Plotter motstanden i besselfunksjonen
hold on                                    
semilogx(f,Ladder_R_tot_ohm,'g-','DisplayName','Kompakt ladder: motstand')  % plotter motstanden i neikirk-ladder
ylabel('Motstand (ohm/m)')                                                  % Navngir Y aksen (ohm)

%graf høgre akse (induktans) 
yyaxis right                                                                % Definerer høyre Y-Akse
semilogx(f,L_H, '--','DisplayName','bessel: induktans')                     % Plotter spolen i besselfunksjonen
semilogx(f,Ladder_L_tot_H, '-','DisplayName','Kompakt ladder: induktans')   % plotter solen i neikirk-ladder
ylabel('Induktans (H/m)')                                                   % Navngir Y aksen
legend
hold off

%% Impedansemodell med Besselfunksjon
function [z_math] = Z_wire (omega, R, sigma, u0)

  A      = sqrt(-1j*omega*sigma*u0);                                        % Normalisert argument for Bessel funksjon 
  J0     = besselj ( 0 , A.* R );                                           % første bessel-function of null-orden
  J1     = besselj ( 1 , A.* R );                                           % første bessel-function of første-orden
  z_math = A./(sigma*2*pi.*R).*J0./J1;                                      % impedanse
  
end






